@@ -77,7 +77,7 @@ void Ldr::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* w
 
     Component::paint( p, option, widget );
 
-    p->drawRect( QRectF(-10.5, -4, 21, 8 ));
+    p->drawRect( QRectF(-11,-4.5, 22, 9 ));
     
     p->drawLine(-5,-11,-1,-7 );
     p->drawLine(-1, -7,-1,-9 );
