@@ -11,6 +11,7 @@
 #include <QLineEdit>
 #include <QTextStream>
 #include <QLabel>
+#include <QSpinBox>
 #include <QCheckBox>
 #include <QDialogButtonBox>
 #include <QPushButton>
@@ -257,7 +258,7 @@ void SubPackage::setBoardMode( bool mode )
             comp->setPos( comp->circPos() );
             comp->setRotation( comp->circRot() );
         }
-        comp->setHidden( mode );
+        comp->setHidden( mode, false, mode );
     }
 }
 
@@ -301,7 +302,7 @@ void SubPackage::setHeight( int height )
     Circuit::self()->update();
 }
 
-Pin* SubPackage::addPin( QString id, QString type, QString label, int pos, int xpos, int ypos, int angle, int length  )
+Pin* SubPackage::addPin( QString id, QString type, QString label, int pos, int xpos, int ypos, int angle, int length, int space )
 {
     PackagePin* pin = new PackagePin( angle, QPoint(xpos, ypos), m_id+"-"+id, pos-1, this ); // pos in package starts at 1
     //pin->setEnabled( false );
@@ -312,6 +313,7 @@ Pin* SubPackage::addPin( QString id, QString type, QString label, int pos, int x
     pin->setPos( QPoint( xpos, ypos ) );
     pin->setPinAngle( angle );
     pin->setLength( length );
+    pin->setSpace( space );
     pin->setLabelText( label );
     pin->setInverted( type == "inverted" || type == "inv" );
     //pin->setFlag( QGraphicsItem::ItemStacksBehindParent, false );
@@ -372,6 +374,11 @@ void SubPackage::setPinAngle( int i )
     update();
 }
 
+void SubPackage::setPinSpace( int space )
+{
+    m_eventPin->setSpace( space );
+}
+
 void SubPackage::invertPin( bool invert )
 {
     m_eventPin->setInverted( invert );
@@ -540,6 +547,7 @@ QString SubPackage::pinEntry( Pin* pin )
     QString length = "length=\""+QString::number( pin->length() )+"\"";
     QString id     = "id=\""+pin->pinId().split( "-" ).last().replace( " ", "" )+"\"";
     QString label  = "label=\""+pin->getLabelText().replace("<","&#x3C;").replace("=","&#x3D;").replace(">","&#x3E;")+"\"";
+    QString space  = "space=\""+QString::number( pin->space() )+"\"";
     QString type;
     if( pin->inverted() ) type = "inv";
     if( pin->unused()   ) type = "nc";
@@ -551,6 +559,7 @@ QString SubPackage::pinEntry( Pin* pin )
             +adjustSize( ypos, 12 )
             +adjustSize( angle, 12 )
             +adjustSize( length, 12 )
+            +adjustSize( space, 12 )
             +adjustSize( id, 10 )
             +adjustSize( label, 12 )
             +"/>\n";
@@ -602,6 +611,13 @@ EditDialog::EditDialog( SubPackage* pack, Pin* eventPin, QWidget* parent )
     idLayout->addWidget( m_idLabel );
     idLayout->addWidget( m_idLineEdit );
 
+    m_spaceLabel = new QLabel( tr("Name Space:") );
+    m_spaceBox = new QSpinBox();
+    m_spaceBox->setValue( eventPin->space() );
+    QHBoxLayout* spaceLayout = new QHBoxLayout;
+    spaceLayout->addWidget( m_spaceLabel );
+    spaceLayout->addWidget( m_spaceBox );
+
     int angle = eventPin->pinAngle();
     int i = 0;
     if     ( angle == 180 ) i = 1;
@@ -631,6 +647,7 @@ EditDialog::EditDialog( SubPackage* pack, Pin* eventPin, QWidget* parent )
     QVBoxLayout* layout = new QVBoxLayout;
     layout->addLayout( nameLayout );
     layout->addLayout( idLayout );
+    layout->addLayout( spaceLayout );
     layout->addLayout( angleLayout );
     layout->addWidget( m_invertCheckBox );
     layout->addWidget( m_unuseCheckBox );
@@ -649,6 +666,9 @@ EditDialog::EditDialog( SubPackage* pack, Pin* eventPin, QWidget* parent )
     connect( m_idLineEdit, &QLineEdit::textEdited,
                      pack, &SubPackage::setPinId, Qt::UniqueConnection );
 
+    connect( m_spaceBox, QOverload<int>::of(&QSpinBox::valueChanged),
+                   pack, &SubPackage::setPinSpace, Qt::UniqueConnection );
+
     connect( m_angleBox, QOverload<int>::of(&QComboBox::currentIndexChanged),
                    pack, &SubPackage::setPinAngle, Qt::UniqueConnection );
 
