@@ -9,6 +9,8 @@
 #include <QObject>
 #include <math.h>
 
+#include "circuitwidget.h"
+
 #include "mcucreator.h"
 #include "datautils.h"
 #include "regwatcher.h"
@@ -77,6 +79,9 @@
 #include "scriptusart.h"
 #include "scriptspi.h"
 #include "scriptprop.h"
+#include "scriptdisplay.h"
+
+#include "watcher.h"
 
 #include "utils.h"
 
@@ -165,6 +170,7 @@ int McuCreator::processFile( QString fileName, bool main )
         else if( part == "intosc")      createIntOsc( &el );
         //else if( part == "extmem" )     createExtMem( &el );
         else if( part == "intmem" )     createIntMem( &el );
+        else if( part == "display" )    createDisplay( &el );
 
         else if( part == "include" )
         {
@@ -175,16 +181,16 @@ int McuCreator::processFile( QString fileName, bool main )
     }
     if( root.hasAttribute("core") )
     {
-        if     ( m_core == "AVR" )      mcu->cpu = new AvrCore( mcu );
-        else if( m_core == "Pic14" )    mcu->cpu = new Pic14Core( mcu );
-        else if( m_core == "Pic14e" )   mcu->cpu = new Pic14eCore( mcu );
-        else if( m_core == "8051" )     mcu->cpu = new I51Core( mcu );
-        else if( m_core == "6502" )     mcu->cpu = new Mcs65Cpu( mcu );
-        else if( m_core == "Z80" )      mcu->cpu = new Z80Core( mcu );
+        if     ( m_core == "AVR" )      mcu->m_cpu = new AvrCore( mcu );
+        else if( m_core == "Pic14" )    mcu->m_cpu = new Pic14Core( mcu );
+        else if( m_core == "Pic14e" )   mcu->m_cpu = new Pic14eCore( mcu );
+        else if( m_core == "8051" )     mcu->m_cpu = new I51Core( mcu );
+        else if( m_core == "6502" )     mcu->m_cpu = new Mcs65Cpu( mcu );
+        else if( m_core == "Z80" )      mcu->m_cpu = new Z80Core( mcu );
         else if( m_core == "scripted" )
         {
             ScriptCpu* cpu = new ScriptCpu( mcu );
-            mcu->cpu = cpu;
+            mcu->m_cpu = cpu;
             m_mcuComp->m_scripted = true;
 
             if( root.hasAttribute("linkable")
@@ -197,12 +203,12 @@ int McuCreator::processFile( QString fileName, bool main )
                 QDomElement e = node.toElement();
                 QString  part = e.tagName();
 
-                if( part == "properties" )
+                if( part == "propertygroup" )
                 {
                     QString group = e.attribute("name");
 
                     QList<ComProperty*> propList;
-                    m_mcuComp->addPropGroup( {group, propList} );
+                    m_mcuComp->addPropGroup( {group, propList, 0} );
 
                     QDomNode node = e.firstChild();
                     while( !node.isNull() )
@@ -225,7 +231,7 @@ int McuCreator::processFile( QString fileName, bool main )
 
             cpu->setScriptFile( m_basePath+"/"+root.attribute("script") );
         }
-        else mcu->cpu = new McuCpu( mcu );
+        else mcu->m_cpu = new McuCpu( mcu );
 
         if( m_newStack ) createStack( &m_stackEl );
     }
@@ -1179,17 +1185,41 @@ void McuCreator::createIntMem( QDomElement* e )
     intMem->m_clkPin = mcu->getIoPin( e->attribute("clkpin") );
 }
 
+void McuCreator::createDisplay( QDomElement* e )
+{
+    QString name = e->attribute("name");
+
+    int width  = e->attribute("width").toInt();
+    int height = e->attribute("height").toInt();
+
+    ScriptDisplay* display = new ScriptDisplay( width, height, name, CircuitWidget::self() );
+
+    m_scriptPerif.push_back( display );
+
+    if( e->hasAttribute("embeed") )
+        m_mcuComp->setBackImage( display->getImage() );
+
+    if( e->hasAttribute("monitorscale") )
+    {
+        mcu->createWatcher();
+        mcu->getWatcher()->addWidget( display );
+
+        double scale = e->attribute("monitorscale").toDouble();
+        display->setMonitorScale( scale );
+    }
+}
+
 void McuCreator::createStack( QDomElement* s )
 {
     QStringList spRegs = s->attribute("spreg").split(",");
-    mcu->cpu->m_spl = mcu->getReg( spRegs.value(0) );
+    mcu->m_cpu->m_spl = mcu->getReg( spRegs.value(0) );
     if( spRegs.size() > 1 )
-        mcu->cpu->m_sph = mcu->getReg( spRegs.value(1) );
+        mcu->m_cpu->m_sph = mcu->getReg( spRegs.value(1) );
 
     QString inc = s->attribute("increment");
 
-    mcu->cpu->m_spPre = inc.contains("pre");
-    mcu->cpu->m_spInc = inc.contains("inc") ? 1:-1;
+    mcu->m_cpu->m_spPre = inc.contains("pre");
+    mcu->m_cpu->m_spInc = inc.contains("inc") ? 1:-1;
 }
 
 void McuCreator::createInterrupts( QDomElement* i )
